@@ -72,24 +72,36 @@ def make_app(global_conf, full_stack=True, static_files=True, **app_conf):
     # Initialize repoze.who
     who_parser = WhoConfig(global_conf['here'])
     who_parser.parse(open(app_conf['who.config_file']))
+
+    if asbool(config.get('openid_enabled', 'true')):
+        from repoze.who.plugins.openid.identification import OpenIdIdentificationPlugin
+        who_parser.identifiers = [i for i in who_parser.identifiers if \
+                not isinstance(i, OpenIdIdentificationPlugin)]
+        who_parser.challengers = [i for i in who_parser.challengers if \
+                not isinstance(i, OpenIdIdentificationPlugin)]
+    
     app = PluggableAuthenticationMiddleware(app,
-                    who_parser.identifiers,
-                    who_parser.authenticators,
-                    who_parser.challengers,
-                    who_parser.mdproviders,
-                    who_parser.request_classifier,
-                    who_parser.challenge_decider,
-                    logging.getLogger('repoze.who'),
-                    logging.WARN, # ignored
-                    who_parser.remote_user_key,
-               )
+                who_parser.identifiers,
+                who_parser.authenticators,
+                who_parser.challengers,
+                who_parser.mdproviders,
+                who_parser.request_classifier,
+                who_parser.challenge_decider,
+                logging.getLogger('repoze.who'),
+                logging.WARN, # ignored
+                who_parser.remote_user_key,
+           )
     
     # Establish the Registry for this application
     app = RegistryManager(app)
 
     if asbool(static_files):
         # Serve static files
-        static_app = StaticURLParser(config['pylons.paths']['static_files'])
+        static_max_age = None if not asbool(config.get('ckan.cache_enabled')) \
+            else int(config.get('ckan.static_max_age', 3600))
+
+        static_app = StaticURLParser(config['pylons.paths']['static_files'],
+                cache_max_age=static_max_age)
         static_parsers = [static_app, app]
 
         # Configurable extra static file paths
@@ -97,7 +109,8 @@ def make_app(global_conf, full_stack=True, static_files=True, **app_conf):
         for public_path in config.get('extra_public_paths', '').split(','):
             if public_path.strip():
                 extra_static_parsers.append(
-                    StaticURLParser(public_path.strip())
+                    StaticURLParser(public_path.strip(),
+                        cache_max_age=static_max_age)
                 )
         app = Cascade(extra_static_parsers+static_parsers)
 
