@@ -11,7 +11,7 @@ from paste.deploy.converters import asbool
 from pylons import c, cache, config, g, request, response, session
 from pylons.controllers import WSGIController
 from pylons.controllers.util import abort as _abort
-from pylons.controllers.util import etag_cache, redirect_to, redirect
+from pylons.controllers.util import redirect_to, redirect
 from pylons.decorators import jsonify, validate
 from pylons.i18n import _, ungettext, N_, gettext
 from pylons.templating import cached_template, pylons_globals
@@ -25,6 +25,7 @@ import ckan.lib.helpers as h
 from ckan.plugins import PluginImplementations, IGenshiStreamFilter
 from ckan.lib.helpers import json
 import ckan.model as model
+from ckan.lib.cache import etag_cache
 
 # nuke cache
 #from pylons import cache
@@ -133,28 +134,39 @@ class BaseController(WSGIController):
     def _get_tag(self, reference):
         return model.Tag.get(reference)
 
-    def _get_request_data(self):
-        self.log.debug('Retrieving request params: %r' % request.params)
-        self.log.debug('Retrieving request POST: %r' % request.POST)
-        try:
-            request_data = request.POST.keys()[0]
-        except Exception, inst:
-            msg = _("Can't find entity data in request POST data %s: %s") % (
-                request.POST, str(inst)
-            )
-            raise ValueError, msg
-        request_data = json.loads(request_data, encoding='utf8')
-        if not isinstance(request_data, dict):
-            raise ValueError, _("Request params must be in form of a json encoded dictionary.")
-        # ensure unicode values
-        for key, val in request_data.items():
-            # if val is str then assume it is ascii, since json converts
-            # utf8 encoded JSON to unicode
-            request_data[key] = self._make_unicode(val)
-        self.log.debug('Request data extracted: %r' % request_data)
-        return request_data
+    @classmethod
+    def _get_request_data(cls):
+        '''Returns a dictionary, extracted from a request. The request data is
+        in POST data and formatted as a dictionary that has been
+        JSON-encoded.
+
+        If there is no data, None or "" is returned.
+        ValueError will be raised if the data is not a JSON-formatted dict.
         
-    def _make_unicode(self, entity):
+        '''
+        cls.log.debug('Retrieving request params: %r' % request.params)
+        cls.log.debug('Retrieving request POST: %r' % request.POST)
+        try:
+            request_data = request.POST.keys()
+        except Exception, inst:
+            msg = _("Could not find the POST data: %r : %s") % \
+                  (request.POST, inst)
+            raise ValueError, msg
+        if request_data:
+            request_data = request_data[0]
+            request_data = json.loads(request_data, encoding='utf8')
+            if not isinstance(request_data, dict):
+                raise ValueError, _("Request params must be in form of a json encoded dictionary.")
+            # ensure unicode values
+            for key, val in request_data.items():
+                # if val is str then assume it is ascii, since json converts
+                # utf8 encoded JSON to unicode
+                request_data[key] = cls._make_unicode(val)
+        cls.log.debug('Request data extracted: %r' % request_data)
+        return request_data
+
+    @classmethod
+    def _make_unicode(cls, entity):
         """Cast bare strings and strings in lists or dicts to Unicode
         """
         if isinstance(entity, str):
@@ -162,12 +174,12 @@ class BaseController(WSGIController):
         elif isinstance(entity, list):
             new_items = []
             for item in entity:
-                new_items.append(self._make_unicode(item))
+                new_items.append(cls._make_unicode(item))
             return new_items
         elif isinstance(entity, dict):
             new_dict = {}
             for key, val in entity.items():
-                new_dict[key] = self._make_unicode(val)
+                new_dict[key] = cls._make_unicode(val)
             return new_dict
         else:
             return entity
