@@ -45,28 +45,23 @@ def resource_list_save(res_dicts, context):
 
     return obj_list
 
-def package_extras_save(extras_dicts, pkg, context):
+def extras_save(extras_dicts, context):
 
     model = context["model"]
     session = context["session"]
+    extras_as_string = context.get("extras_as_string", False)
 
     result_dict = {}
     for extra_dict in extras_dicts:
-        result_dict[extra_dict["key"]] = json.loads(extra_dict["value"])
+        if extra_dict.get("deleted"):
+            continue
+        if extras_as_string:
+            result_dict[extra_dict["key"]] = extra_dict["value"]
+        else:
+            result_dict[extra_dict["key"]] = json.loads(extra_dict["value"])
 
     return result_dict
 
-def group_extras_save(extras_dicts, pkg, context):
-
-    model = context["model"]
-    session = context["session"]
-
-    obj_dict = {}
-    for extra_dict in extras_dicts:
-        obj = table_dict_save(extra_dict, model.GroupExtra, context)
-        obj_dict[extra_dict["key"]] = obj
-
-    return obj_dict
 
 def tag_list_save(tag_dicts, context):
 
@@ -78,7 +73,7 @@ def tag_list_save(tag_dicts, context):
         obj = table_dict_save(table_dict, model.Tag, context)
         tag_list.append(obj)
 
-    return tag_list
+    return list(set(tag_list))
 
 def group_list_save(group_dicts, context):
 
@@ -115,6 +110,7 @@ def package_dict_save(pkg_dict, context):
 
     model = context["model"]
     package = context.get("package")
+    allow_partial_update = context.get("allow_partial_update", False)
     if package:
         pkg_dict["id"] = package.id 
     Package = model.Package
@@ -126,22 +122,22 @@ def package_dict_save(pkg_dict, context):
         pkg.resources[:] = resources
 
     tags = tag_list_save(pkg_dict.get("tags", []), context)
-    if tags:
+    if tags or not allow_partial_update:
         pkg.tags[:] = tags
 
     groups = group_list_save(pkg_dict.get("groups", []), context)
-    if groups:
+    if groups or not allow_partial_update:
         pkg.groups[:] = groups
 
     subjects = pkg_dict.get("relationships_as_subject", [])
-    if subjects:
+    if subjects or not allow_partial_update:
         pkg.relationships_as_subject[:] = relationship_list_save(subjects, context)
     objects = pkg_dict.get("relationships_as_object", [])
-    if objects:
+    if objects or not allow_partial_update:
         pkg.relationships_as_object[:] = relationship_list_save(objects, context)
 
-    extras = package_extras_save(pkg_dict.get("extras", {}), pkg, context)
-    if extras:
+    extras = extras_save(pkg_dict.get("extras", {}), context)
+    if extras or not allow_partial_update:
         old_extras = set(pkg.extras.keys())
         new_extras = set(extras.keys())
         for key in old_extras - new_extras:
@@ -157,18 +153,22 @@ def group_dict_save(group_dict, context):
     model = context["model"]
     session = context["session"]
     group = context.get("group")
+    allow_partial_update = context.get("allow_partial_update", False)
+    
     Group = model.Group
     Package = model.Package
     if group:
         group_dict["id"] = group.id 
 
     group = table_dict_save(group_dict, Group, context)
-
-    extras = group_extras_save(group_dict.get("extras", []), group, context)
-
-    group._extras.clear()
-    for key, value in extras.iteritems():
-        group._extras[key] = value
+    extras = extras_save(group_dict.get("extras", {}), context)
+    if extras or not allow_partial_update:
+        old_extras = set(group.extras.keys())
+        new_extras = set(extras.keys())
+        for key in old_extras - new_extras:
+            del group.extras[key]
+        for key in new_extras:
+            group.extras[key] = extras[key] 
 
     package_dicts = group_dict.get("packages", [])
 
@@ -180,10 +180,12 @@ def group_dict_save(group_dict, context):
         if id:
             pkg = session.query(Package).get(id)
         if not pkg:
-            pkg = session.query(Package).filter_by(name=package["name"]).one()
-        packages.append(pkg)
+            pkg = session.query(Package).filter_by(name=package["name"]).first()
+        if pkg:
+            packages.append(pkg)
 
-    group.packages[:] = packages
+    if packages or not allow_partial_update:
+        group.packages[:] = packages
 
     return group
 
@@ -212,7 +214,6 @@ def package_api_to_dict(api1_dict, context):
                 if extras_value is not None:
                     new_value.append({"key": extras_key,
                                       "value": json.dumps(extras_value)})
-
         dictized[key] = new_value
 
     groups = dictized.pop('groups', None)
