@@ -1,6 +1,7 @@
 import logging
 
 from paste.util.multidict import MultiDict 
+from paste.deploy.converters import asbool
 from ckan import model
 
 log = logging.getLogger(__name__)
@@ -145,9 +146,12 @@ class QueryOptions(dict):
     def validate(self):
         for key, value in self.items():
             if key in self.BOOLEAN_OPTIONS:
-                value = value == 1 or value
+                value = asbool(value)
             elif key in self.INTEGER_OPTIONS:
-                value = int(value)
+                try:
+                    value = int(value)
+                except ValueError:
+                    raise SearchError('Value for search option %r must be an integer but received %r' % (key, value))
             self[key] = value    
     
     def __getattr__(self, name):
@@ -233,14 +237,13 @@ class QueryParser(object):
     
     def validate(self):
         """ Check that this is a valid query. """
-        if not len(self.query):
-            raise SearchError("No query has been specified")
+        pass
     
     def __str__(self):
         return self.query
         
     def __repr__(self):
-        return "Query(%s)" % self
+        return "Query(%r)" % self.query
 
 
 class SearchIndex(object):
@@ -282,5 +285,9 @@ class SearchIndex(object):
     def clear(self):
         """ Delete the complete index. """
         log.debug("NOOP Index reset")
+
+    def get_all_entity_ids(self):
+        """ Return a list of entity IDs in the index. """
+        raise NotImplemented
         
 class NoopSearchIndex(SearchIndex): pass
