@@ -1,4 +1,5 @@
 import logging
+import re
 
 import ckan.authz
 from ckan.plugins import PluginImplementations, IGroupController, IPackageController
@@ -14,14 +15,69 @@ from ckan.logic.schema import (default_update_group_schema,
 from ckan.lib.navl.dictization_functions import validate
 log = logging.getLogger(__name__)
 
+def prettify(field_name):
+    field_name = re.sub('(?<!\w)[Uu]rl(?!\w)', 'URL', field_name.replace('_', ' ').capitalize())
+    return _(field_name.replace('_', ' '))
 
+def package_error_summary(error_dict):
+
+    error_summary = {}
+    for key, error in error_dict.iteritems():
+        if key == 'resources':
+            error_summary[_('Resources')] = _('Package resource(s) incomplete')
+        elif key == 'extras':
+            error_summary[_('Extras')] = _('Missing Value')
+        elif key == 'extras_validation':
+            error_summary[_('Extras')] = error[0]
+        else:
+            error_summary[_(prettify(key))] = error[0]
+    return error_summary
+
+def group_error_summary(error_dict):
+
+    error_summary = {}
+    for key, error in error_dict.iteritems():
+        if key == 'extras':
+            error_summary[_('Extras')] = _('Missing Value')
+        elif key == 'extras_validation':
+            error_summary[_('Extras')] = error[0]
+        else:
+            error_summary[_(prettify(key))] = error[0]
+    return error_summary
+
+def check_group_auth(data_dict, context):
+    model = context['model']
+    pkg = context.get("package")
+
+    ## hack as api does not allow groups
+    if context.get("allow_partial_update"):
+        return
+    
+    group_dicts = data_dict.get("groups", [])
+    groups = set()
+    for group_dict in group_dicts:
+        id = group_dict.get('id')
+        if not id:
+            continue
+        grp = model.Group.get(id)
+        if grp is None:
+            raise NotFound(_('Group was not found.'))
+        groups.add(grp)
+
+    if pkg:
+        groups = groups - set(pkg.groups)
+
+    for group in groups:
+        check_access(group, model.Action.EDIT, context)
 
 def package_update(data_dict, context):
 
     model = context['model']
     user = context['user']
     id = context["id"]
+    preview = context.get('preview', False)
     schema = context.get('schema') or default_update_package_schema()
+    model.Session.remove()
 
     pkg = model.Package.get(id)
     context["package"] = pkg
@@ -30,22 +86,29 @@ def package_update(data_dict, context):
         raise NotFound(_('Package was not found.'))
 
     check_access(pkg, model.Action.EDIT, context)
+    check_group_auth(data_dict, context)
+
+    data, errors = validate(data_dict, schema, context)
 
-    data, errors = validate(data_dict,
-                            default_update_package_schema(),
-                            context)
     if errors:
-        raise ValidationError(errors)
+        model.Session.rollback()
+        raise ValidationError(errors, package_error_summary(errors))
 
-    rev = model.repo.new_revision()
-    rev.author = user
-    rev.message = _(u'REST API: Update object %s') % pkg.name
+    if not preview:
+        rev = model.repo.new_revision()
+        rev.author = user
+        if 'message' in context:
+            rev.message = context['message']
+        else:
+            rev.message = _(u'REST API: Create object %s') % data.get("name")
 
     pkg = package_dict_save(data, context)
-    for item in PluginImplementations(IPackageController):
-        item.edit(pkg)
 
-    model.repo.commit()        
+    if not preview:
+        for item in PluginImplementations(IPackageController):
+            item.edit(pkg)
+        model.repo.commit()        
+
     return package_dictize(pkg, context)
 
 
@@ -97,15 +160,12 @@ def package_relationship_update(data_dict, context):
     return _update_package_relationship(entity, comment, context)
 
 
-def group_update_rest(data_dict, context):
-
-    dictized = group_api_to_dict(data_dict, context)
-    return group_update(dictized, context)
 
 def group_update(data_dict, context):
 
     model = context['model']
     user = context['user']
+    schema = context.get('schema') or default_update_group_schema()
     id = context['id']
 
     group = model.Group.get(id)
@@ -115,17 +175,20 @@ def group_update(data_dict, context):
 
     check_access(group, model.Action.EDIT, context)
 
-    data, errors = validate(data_dict,
-                            default_update_group_schema(),
-                            context)
+    data, errors = validate(data_dict, schema, context)
     if errors:
-        raise ValidationError(errors)
+        model.Session.rollback()
+        raise ValidationError(errors, group_error_summary(errors))
 
     rev = model.repo.new_revision()
     rev.author = user
     
+    if 'message' in context:
+        rev.message = context['message']
+    else:
+        rev.message = _(u'REST API: Create object %s') % data.get("name")
+
     group = group_dict_save(data, context)
-    rev.message = _(u'REST API: Update object %s') % group.name
 
     for item in PluginImplementations(IGroupController):
         item.edit(group)
@@ -144,6 +207,17 @@ def package_update_rest(data_dict, context):
     id = context["id"]
     pkg = model.Package.get(id)
     context["package"] = pkg
+    context["allow_partial_update"] = True
     dictized_package = package_api_to_dict(data_dict, context)
     return package_update(dictized_package, context)
 
+def group_update_rest(data_dict, context):
+
+    model = context['model']
+    id = context["id"]
+    group = model.Group.get(id)
+    context["group"] = group
+    context["allow_partial_update"] = True
+    dictized_package = group_api_to_dict(data_dict, context)
+    return group_update(dictized_package, context)
+
