@@ -3,20 +3,24 @@ from ckan.lib.navl.validators import (ignore_missing,
                                       not_empty,
                                       empty,
                                       ignore,
-                                      both_not_empty,
                                       if_empty_same_as,
-                                      not_missing
+                                      not_missing,
+                                      ignore_empty
                                      )
 from ckan.logic.validators import (package_id_not_changed,
-                                             package_id_exists,
-                                             package_id_or_name_exists,
-                                             extras_unicode_convert,
-                                             name_validator,
-                                             package_name_validator,
-                                             group_name_validator,
-                                             tag_length_validator,
-                                             tag_name_validator,
-                                             tag_not_uppercase)
+                                   package_id_exists,
+                                   package_id_or_name_exists,
+                                   extras_unicode_convert,
+                                   name_validator,
+                                   package_name_validator,
+                                   group_name_validator,
+                                   tag_length_validator,
+                                   tag_name_validator,
+                                   tag_string_convert,
+                                   duplicate_extras_key,
+                                   ignore_not_admin,
+                                   no_http,
+                                   tag_not_uppercase)
 from formencode.validators import OneOf
 import ckan.model
 
@@ -24,7 +28,7 @@ import ckan.model
 def default_resource_schema():
 
     schema = {
-        'id': [ignore_missing, unicode],
+        'id': [ignore_empty, unicode],
         'revistion_id': [ignore_missing, unicode],
         'resource_group_id': [ignore],
         'package_id': [ignore],
@@ -54,7 +58,7 @@ def default_package_schema():
 
     schema = {
         'id': [ignore_missing, unicode, package_id_exists],
-        'revision_id': [ignore_missing, unicode],
+        'revision_id': [ignore],
         'name': [not_empty, unicode, name_validator, package_name_validator],
         'title': [if_empty_same_as("name"), unicode],
         'author': [ignore_missing, unicode],
@@ -65,7 +69,7 @@ def default_package_schema():
         'notes': [ignore_missing, unicode],
         'url': [ignore_missing, unicode],#, URL(add_http=False)],
         'version': [ignore_missing, unicode],
-        'state': [ignore],
+        'state': [ignore_not_admin, ignore_missing],
         '__extras': [ignore],
         '__junk': [empty],
         'resources': default_resource_schema(),
@@ -74,10 +78,10 @@ def default_package_schema():
         'relationships_as_object': default_relationship_schema(),
         'relationships_as_subject': default_relationship_schema(),
         'groups': {
+            'id': [ignore_missing, unicode],
             '__extras': [ignore],
         }
     }
-
     return schema
 
 def default_create_package_schema():
@@ -96,18 +100,42 @@ def default_update_package_schema():
 
     return schema
 
+def package_form_schema():
+
+    schema = default_package_schema()
+    ##new
+    schema['log_message'] = [unicode, no_http]
+    schema['groups'] = {
+            'id': [ignore_missing, unicode],
+            '__extras': [empty],
+            'name': [ignore, unicode],
+    }
+    schema['tag_string'] = [ignore_missing, tag_string_convert]
+    schema['extras_validation'] = [duplicate_extras_key, ignore]
+    schema['save'] = [ignore]
+    schema['preview'] = [ignore]
+    schema['return_to'] = [ignore]
+
+    ##changes
+    schema.pop("id")
+    schema.pop('tags')
+    schema.pop('relationships_as_object')
+    schema.pop('revision_id')
+    schema.pop('relationships_as_subject')
+    return schema
 
 def default_group_schema():
 
     schema = {
         'id': [ignore_missing, unicode],
-        'revision_id': [ignore_missing, unicode],
+        'revision_id': [ignore],
         'name': [not_empty, unicode, name_validator, group_name_validator],
         'title': [ignore_missing, unicode],
         'description': [ignore_missing, unicode],
         'state': [ignore],
         'created': [ignore],
         'extras': default_extras_schema(),
+        '__extras': [ignore],
         'packages': {
             "id": [not_empty, unicode, package_id_or_name_exists],
             "__extras": [ignore]
@@ -115,11 +143,22 @@ def default_group_schema():
     }
     return schema
 
+def group_form_schema():
+    schema = default_group_schema()
+    #schema['extras_validation'] = [duplicate_extras_key, ignore]
+    schema['packages'] = {
+        "name": [not_empty, unicode],
+        "__extras": [ignore]
+    }
+    return schema
+
+
 def default_update_group_schema():
     schema = default_group_schema()
     schema["name"] = [ignore_missing, group_name_validator, unicode]
     return schema
 
+
 def default_extras_schema():
 
     schema = {
@@ -127,6 +166,7 @@ def default_extras_schema():
         'key': [not_empty, unicode],
         'value': [not_missing, unicode],
         'state': [ignore],
+        'deleted': [ignore_missing],
     }
     return schema
 
