@@ -7,14 +7,16 @@ __all__ = [
     'Interface',
     'IGenshiStreamFilter', 'IRoutes',
     'IMapper', 'ISession',
+    'IMiddleware',
     'IDomainObjectModification', 'IGroupController', 
     'IPackageController', 'IPluginObserver',
-    'IConfigurable', 'IConfigurer'
+    'IConfigurable', 'IConfigurer', 'IAuthorizer'
 ]
 
 from inspect import isclass
 from pyutilib.component.core import Interface as _pca_Interface
 
+
 class Interface(_pca_Interface):
 
     @classmethod
@@ -31,6 +33,15 @@ class Interface(_pca_Interface):
             return False
 
 
+class IMiddleware(Interface):
+    '''Hook into Pylons middleware stack
+    '''
+    def make_middleware(self, app, config):
+        '''Return an app configured with this middleware
+        '''
+        return app
+
+
 class IGenshiStreamFilter(Interface):
     '''
     Hook into template rendering.
@@ -47,6 +58,7 @@ class IGenshiStreamFilter(Interface):
         """
         return stream
 
+
 class IRoutes(Interface):
     """
     Plugin into the setup of the routes map creation.
@@ -261,3 +273,31 @@ class IConfigurer(Interface):
         :param config: ``pylons.config`` object
         """
 
+
+class IAuthorizer(Interface):
+    """
+    Allow customisation of default Authorization implementation
+    """
+    def get_authorization_groups(self, username):
+        """
+        Called by Authorizer to extend the list of groups to which a
+        user belongs.  Should return a list of AuthorizationGroups.
+        """
+
+    def get_roles(self, username, domain_obj):
+        """
+        Called by Authorizer to extend the list of roles which a user
+        has in the context of the supplied object.  Should return a
+        list of strings which are the names of valid UserObjectRoles.
+        """
+
+    def is_authorized(self, username, action, domain_obj):
+        """
+        Called by Authorizer to assert that a user ```username``` can
+        perform ``action``` on ```domain_obj```.
+
+        Should return True or False.  A value of False will allow
+        other Authorizers to run; True will shortcircuit and return.
+        """
+        
+
