@@ -1,3 +1,5 @@
+from nose.tools import assert_equal
+
 from ckan.tests import *
 import ckan.model as model
 
@@ -8,7 +10,7 @@ class TestPackage:
     def setup_class(self):
         CreateTestData.create()
         self.name = u'geodata'
-        self.notes = u'Written by Puccini'
+        self.notes = 'A <b>great</b> package <script href="dodgy.js"/> like package:pollution_stats'
         pkgs = model.Session.query(model.Package).filter_by(name=self.name).all()
         for p in pkgs:
             p.purge()
@@ -24,6 +26,7 @@ class TestPackage:
     @classmethod
     def teardown_class(self):
         pkg1 = model.Session.query(model.Package).filter_by(name=self.name).one()
+        
         pkg1.purge()
         model.Session.commit()
         model.repo.rebuild_db()
@@ -84,6 +87,8 @@ class TestPackage:
         assert out['tags'] == [tag.name for tag in pkg.tags]
         assert out['metadata_modified'] == pkg.metadata_modified.isoformat()
         assert out['metadata_created'] == pkg.metadata_created.isoformat()
+        assert_equal(out['notes'], pkg.notes)
+        assert_equal(out['notes_rendered'], '<p>A <b>great</b> package [HTML_REMOVED] like <a href="/package/pollution_stats">package:pollution_stats</a>\n</p>')
 
 
 class TestPackageWithTags:
@@ -113,20 +118,6 @@ class TestPackageWithTags:
 
     @classmethod
     def teardown_class(self):
-        # should only be one but maybe things have gone wrong
-        # p = model.Package.by_name(self.pkgname)
-        pkgs = model.Session.query(model.Package).filter_by(name=self.pkgname)
-        for p in pkgs:
-            for pt in p.package_tags:
-                pt.purge()
-            p.purge()
-        t1 = model.Tag.by_name(self.tagname)
-        t1.purge()
-        t2 = model.Tag.by_name(self.tagname2)
-        t2.purge()
-        t3 = model.Tag.by_name(self.tagname3)
-        t3.purge()
-        model.Session.commit()
         model.repo.rebuild_db()
 
     def test_1(self):
@@ -383,3 +374,17 @@ class TestRelatedRevisions:
         test_res(diff, self.res1, 'hash', 'abc123')
         test_res(diff, self.res1, 'state', 'active')
         test_res(diff, self.res2, 'url', 'http://url2.com')
+
+class TestPackagePurge:
+    @classmethod
+    def setup_class(self):
+        CreateTestData.create()
+    def test_purge(self):
+        pkgs = model.Session.query(model.Package).all()
+        for p in pkgs:
+           p.purge()
+        model.Session.commit()
+        pkgs = model.Session.query(model.Package).all()
+        assert len(pkgs) == 0
+
+
